# <b> mkfst-py </b>
[![PyPI version](https://img.shields.io/pypi/v/mkfst?color=blue)](https://pypi.org/project/mkfst/)
[![License](https://img.shields.io/github/license/hyper-light/mkfst-py)](https://github.com/hyper-light/mkfst-py/blob/main/LICENSE)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](https://github.com/hyper-light/mkfst-py/blob/main/CODE_OF_CONDUCT.md)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mkfst?color=red)](https://pypi.org/project/mkfst/)


| Package     | Mkfst-Py                                                        |
| ----------- | -----------                                                     |
| Version     | 0.4.3                                                           |
| Download    | https://pypi.org/project/mkfst-py/                              | 
| Source      | https://github.com/hyper-light/mkfst-py                         |
| Keywords    | http, rest, framework, web, api                                 |

MKFST (Make Fast) is a high-performance, async, non-ASGI, Python HTTP webserver framework. It's designed to bridge the gap between software like LinkerD and your traditional web framework, offering features like rate limiting, circuit breaking, built-in request-level compression or decompression, AESGCM256 request and response encryption, and more.

MKFST also supports FastAPI-like automatic OpenAPI 3.1 spec endpont documentation out of the box, a powerful asynchronous task system to help you run work you'd normally defer to runners like Celery, and even Snowflake ID generation so you can realize all your distributed web needs.
